@@ -22,7 +22,6 @@ from cognite.air.constants import (
 )
 from cognite.air.utils import valfilter
 from cognite.client.data_classes import Event, EventList
-from cognite.client.exceptions import CogniteDuplicatedError
 
 
 @enum.unique
@@ -96,17 +95,7 @@ class AIREventsAPI(BaseAPIClient):
             raise TypeError(f"Expected single (or list of) Event object(s) ({Event})")
 
         self._make_events_air_compatible_inplace(items)
-        try:
-            result = self.client.events.create(items[0] if single_item else items)
-            return result
-        except CogniteDuplicatedError as err:
-            ev_fail = err.failed[0]
-            existing_ev = self.client.events.retrieve(external_id=ev_fail.external_id)
-            msg = (
-                f"Event ext_id: '{ev_fail.external_id}' already exists.\nFailed event: {ev_fail}."
-                f"\nExisting event: {existing_ev}"
-            )
-            raise CogniteDuplicatedError(msg) from None
+        return self.client.events.create(items[0] if single_item else items)
 
     def update(self, event: Union[Event, List[Event]]) -> Union[Event, EventList]:
         # TODO: Support partial event updates using EventUpdate
