@@ -1,4 +1,5 @@
 import json
+from collections.abc import Iterable
 from typing import Union
 
 
@@ -48,3 +49,22 @@ def is_string_truthy(bool_like):
         raise TypeError(f"Expected one of {[bool, str, None]}, got {type(bool_like)}")
 
     return bool_like.capitalize() == "True"
+
+
+def validate_arg_type(enforced_types):
+    """
+    Produces decorators that type check their input functions first argument
+    to be one of the given expected and enforced types.
+    """
+    enforced_types = tuple(enforced_types if isinstance(enforced_types, Iterable) else [enforced_types])
+    assert all(isinstance(exp_type, type) for exp_type in enforced_types)
+
+    def decorator(fn):
+        def wrapper(arg, **kwargs):
+            if not isinstance(arg, enforced_types):
+                raise TypeError(f"Expected input arg type to one of {enforced_types}, not {type(arg)}")
+            return fn(arg, **kwargs)
+
+        return wrapper
+
+    return decorator
